# Sets the Playback Range field to a random n-second range within the file
# The default value is 30, which can me manually modified below, or via
# the value in an expression column in the view named "Playback Duration".

package RandomPlaybackRange;

use v5.16;
use strict;
use warnings;

my $def_playback_duration = 30;	# default: 30 seconds as the random track playback duration

our %callbacks = (
    perfile => \&do_perfile,
    post    => undef,
);

# Per-row callback function
sub do_perfile {
    my ($cellval, $row) = @_;

    return undef unless exists $row->{'duration'};

    # use the view's Playback Duration value, or the default defined above
    my $playback_duration = $row->{'playback duration'} // $def_playback_duration;
    $playback_duration ||= $def_playback_duration;

    my @duration = split /:/, $row->{'duration'};
    my $duration = pop @duration;
    $duration +=   60 * pop @duration if @duration;
    $duration += 3600 * pop @duration if @duration;
    #say "Duration seconds: $duration";

    my ($start, $end) = (0, $duration);
    if ($playback_duration < $duration) {
	$start = int(rand($duration));
	$start = $duration - $playback_duration if $start + $playback_duration > $duration;
	$end = $start + $playback_duration;

    }

    $start *= 1000;
    $end *= 1000;
    main::debug "Playback Range: $start-$end";
    return "$start-$end";
}

1;
